aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorYang Xu <yang.xu@futurewei.com>2019-06-16 22:52:41 -0400
committerGary Wu <gary.wu@futurewei.com>2019-06-17 04:12:50 +0000
commitcde4f9d521b310be701fc76025697f1052a7c846 (patch)
tree8ece2714f1bfeddb09d5ab82935cf19364e62898
parentd8f9aac6779d1884d65c37cbcc2c7a87fc0d5ffb (diff)
Remove mariadb shared databases in cleanup script
Signed-off-by: Yang Xu <yang.xu@futurewei.com> Issue-ID: INT-1105 Change-Id: I3d4f8777f894e60660cb78e176bc9b81fd02ae6c
-rwxr-xr-xdeployment/heat/onap-rke/scripts/cleanup.sh14
1 files changed, 13 insertions, 1 deletions
diff --git a/deployment/heat/onap-rke/scripts/cleanup.sh b/deployment/heat/onap-rke/scripts/cleanup.sh
index 324badfb9..7d8dd5c68 100755
--- a/deployment/heat/onap-rke/scripts/cleanup.sh
+++ b/deployment/heat/onap-rke/scripts/cleanup.sh
@@ -17,7 +17,19 @@ fi
if [ $COMPONENT == "sdc" ] || [ $COMPONENT == "SDC" ]; then
for keyspace in sdctitan sdcrepository sdcartifact sdccomponent sdcaudit; do
- kubectl exec -it dev-cassandra-cassandra-0 -- cqlsh -u cassandra -p cassandra -e "drop keyspace ${keyspace}"
+ kubectl exec dev-cassandra-cassandra-0 -- cqlsh -u cassandra -p cassandra -e "drop keyspace ${keyspace}"
+ done
+fi
+
+if [ $COMPONENT == "so" ] || [ $COMPONENT == "SO" ]; then
+ for database in camundabpmn catalogdb requestdb; do
+ kubectl exec dev-mariadb-galera-mariadb-galera-0 -- mysql -uroot -psecretpassword -e "drop database ${database}"
+ done
+fi
+
+if [ $COMPONENT == "sdnc" ] || [ $COMPONENT == "SDNC" ]; then
+ for database in sdnctl; do
+ kubectl exec dev-mariadb-galera-mariadb-galera-0 -- mysql -uroot -psecretpassword -e "drop database ${database}"
done
fi